package ecommerce

import "github.com/crowdmob/goamz/ecommerce"

Index

Types

type ProductAdvertising

type ProductAdvertising struct {
	// contains filtered or unexported fields
}

ProductAdvertising provides methods for querying the product advertising API

func New

func New(auth aws.Auth, associateTag string) (p *ProductAdvertising, err error)

New creates a new ProductAdvertising client

func (*ProductAdvertising) PerformOperation

func (p *ProductAdvertising) PerformOperation(operation string, params map[string]string) (resp *http.Response, err error)

PerformOperation is the main method used for interacting with the product advertising API

Source Files

ecommerce.go

Version
v0.0.0-20150128194925-3a06871fe9fc (latest)
Published
Jan 28, 2015
Platform
linux/amd64
Imports
2 packages
Last checked
10 months ago

Tools for package owners.