package iamtest

import "github.com/crowdmob/goamz/iam/iamtest"

Package iamtest implements a fake IAM provider with the capability of inducing errors on any given operation, and retrospectively determining what operations have been carried out.

Index

Types

type Server

type Server struct {
	// contains filtered or unexported fields
}

Server implements an IAM simulator for use in tests.

func NewServer

func NewServer() (*Server, error)

func (*Server) Quit

func (srv *Server) Quit() error

Quit closes down the server.

func (*Server) URL

func (srv *Server) URL() string

URL returns a URL for the server.

Source Files

server.go

Version
v0.0.0-20150128194925-3a06871fe9fc (latest)
Published
Jan 28, 2015
Platform
linux/amd64
Imports
8 packages
Last checked
10 months ago

Tools for package owners.