package s3test
import "github.com/crowdmob/goamz/s3/s3test"
Index ¶
Types ¶
type Config ¶
type Config struct {
// Send409Conflict controls how the Server will respond to calls to PUT on a
// previously existing bucket. The default is false, and corresponds to the
// us-east-1 s3 enpoint. Setting this value to true emulates the behaviour of
// all other regions.
// http://docs.amazonwebservices.com/AmazonS3/latest/API/ErrorResponses.html
Send409Conflict bool
}
Config controls the internal behaviour of the Server. A nil config is the default and behaves as if all configurations assume their default behaviour. Once passed to NewServer, the configuration must not be modified.
type CreateBucketConfiguration ¶
type CreateBucketConfiguration struct {
LocationConstraint string
}
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server is a fake S3 server for testing purposes. All of the data for the server is kept in memory.
func NewServer ¶
func (*Server) Quit ¶
func (srv *Server) Quit()
Quit closes down the server.
func (*Server) URL ¶
URL returns a URL for the server.
Source Files ¶
- Version
- v0.0.0-20150128194925-3a06871fe9fc (latest)
- Published
- Jan 28, 2015
- Platform
- linux/amd64
- Imports
- 19 packages
- Last checked
- 10 months ago –
Tools for package owners.